from .auth import *
from instagrapi import Client
from instagrapi.exceptions import LoginRequired
import os

def login_user(username, password):

    print("Logging in user...")

    # Setup client session and delay to avoid suspicion
    cl = Client()
    cl.delay_range = [1, 3]
    SESSION_PATH = s = os.path.join(os.path.expanduser("~"),".igsave_session.json")
    session_exist = os.path.exists(SESSION_PATH)

    login_via_session = False

    if session_exist:
        try:
            session = cl.load_settings(SESSION_PATH)
            cl.set_settings(session)
            cl.login(username, password)

            # Check if session is valid
            try:
                cl.get_timeline_feed()
            except LoginRequired:
                print("Session is invalid, need to login via username and password")

                # Use the same device uuids across logins
                old_session = cl.get_settings()
                cl.set_settings({})
                cl.set_uuids(old_session["uuids"])

                cl.login(username, password)

            login_via_session = True
            cl.dump_settings(SESSION_PATH)
            print("✅ Login via session successful")

        except Exception as e:
            print("Couldn't login user using session information: %s" % e)

    if not login_via_session:
        try:
            print("Attempting to login via username and password. username: %s" % username)
            if cl.login(username, password):
                cl.dump_settings(SESSION_PATH)
                print("✅ Login via passoword is successful")

        except Exception as e:
            # print("Error message: %s" % e)
            print("❌ Login failed. Check if your credentials are correct and try again!")
            delete_cred()
            quit()

    return cl

def save_story(cl, username):
    
    # Get UserID from username
    user_info = cl.user_info_by_username_v1(username).model_dump()
    userid = user_info["pk"]
    # userid = cl.user_id_from_username(username)
    print("Found user ID: "+userid)
    
    # Get story count
    stories = cl.user_stories(userid)
    print("User story count: "+str(len(stories)))

    # Save story if not exists
    for s in stories:
        storid = s.pk
        if not os.path.exists("stories"):
            os.makedirs("stories")
        if not (os.path.exists(f"stories/{username}_{storid}.mp4") or os.path.exists(f"stories/{username}_{storid}.jpg")):
            cl.story_download(storid, f"{username}_{storid}", "./stories")
            print(f"Story {storid} successfully downloaded!")
        else:
            print(f"Story {storid} already exists, skipping...")

def main():
    print("💾 Instastorysaver")
    username, password = get_credentials()
    cl = login_user(username, password)
    print("ℹ️ To save multiple users, simply seperate each user by a whitespace (e.g.: foo bar etc)")
    print("ℹ️ To quit the program, simply input: exit")
    while True:
        users = input("Input usernames to save: ")
        if users == "exit":
            quit()
        for username in users.split():
            save_story(cl, username)

if __name__ == "__main__":
    main()



import json
import os
import getpass
import argparse

CRED_PATH = s = os.path.join(os.path.expanduser("~"),".igsave_cred.json")

def save_cred(username, password):
    # save user credentials to a JSON file.
    cred = {"username": username, "password": password}
    with open(CRED_PATH, "w") as file:
        json.dump(cred, file, indent=4)
    print("✅ Credentials saved successfully!")

def load_cred():
    # load user credentials if they exist.
    if os.path.exists(CRED_PATH):
        with open(CRED_PATH, "r") as file:
            return json.load(file)
    return None

def delete_cred():
    # delete the stored credentials.
    if os.path.exists(CRED_PATH):
        os.remove(CRED_PATH)
        print("✅ Credentials deleted successfully.")
    else:
        print("⚠️ No stored credentials found.")

def prompt_for_credentials():
    # prompt the user for login credentials.
    username = input("Enter username: ")
    password = getpass.getpass("Enter password: ")
    return username, password

def get_credentials():
    parser = argparse.ArgumentParser(description="💾 Instastorysaver by Hansel11")
    parser.add_argument("--login", action="store_true", help="add or update login credentials")
    parser.add_argument("--logout", action="store_true", help="remove saved sessions and credentials")

    args = parser.parse_args()
    
    if args.logout:
        delete_cred()
        quit()
    elif args.login:
        print("🔄 Resetting login credentials...")
        delete_cred()
        username, password = prompt_for_credentials()
        save_cred(username, password)
        quit()
    else:
        credentials = load_cred()
        if credentials:
            print(f"🔑 Credentials found! username: {credentials['username']}")
            username, password = credentials['username'], credentials['password']
        else:
            print("🔓 No credentials found.")
            username, password = prompt_for_credentials()
            save_cred(username, password)
        return (username, password)
    
    


from setuptools import *

with open("README.md", "r") as fh:
    long_description = fh.read()

requirements = list()
with open("requirements.txt", "r") as file:
    requirements = [r for r in file.readlines() if len(r) > 0]


setup (
    name="instastorysaver",
    author="Hansel11",
    version="0.1.1",
    packages=find_packages(),
        entry_points={
        "console_scripts": ["igsave=instastorysaver:main"],
    },
    description="Instagram Story Saver",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Hansel11/instagram-story-saver",
    include_package_data=True,
    install_requires=requirements,
)
